@@ -7,5 +7,5 @@ use Net::Inetd;
 my $Inetd = Net::Inetd->new;
 
 $, = "\n";
-print @{$Inetd->dump_enabled}; print "\n\n";
+print @{$Inetd->dump_enabled},"\n";
 print @{$Inetd->dump_disabled}; print "\n";
